@@ -36,6 +36,17 @@ def _mocked_listdir(path):
     return ['openstack-nova.spec']
 
 
+def _mocked_get_environ(param, default=None):
+    if param == 'USER':
+        return 'myuser'
+    elif param == 'MOCK_CONFIG':
+        return '/tmp/test.cfg'
+    elif param == 'RELEASE_DATE':
+        return '20150102034455'
+    elif param == 'RELEASE_NUMBERING':
+        return '0.date.hash'
+
+
 @mock.patch('dlrn.drivers.downstream.urlopen', side_effect=_mocked_versions)
 class TestDriverDownstream(base.TestCase):
     def setUp(self):
@@ -75,7 +86,7 @@ class TestDriverDownstream(base.TestCase):
             'project': 'nova',
             'conf': 'rpmfactory-core',
             'upstream': 'git://git.openstack.org/openstack/nova',
-            'patches': 'http://review.rdoproject.org/r/p/openstack/nova.git',
+            'patches': 'http://review.rdoproject.org/r/openstack/nova.git',
             'distgit': 'git://git.example.com/rpms/nova',
             'master-distgit':
                 'git://git.example.com/rpms/nova',
@@ -128,7 +139,7 @@ class TestDriverDownstream(base.TestCase):
             'project': 'nova',
             'conf': 'rpmfactory-core',
             'upstream': 'git://git.openstack.org/openstack/nova',
-            'patches': 'http://review.rdoproject.org/r/p/openstack/nova.git',
+            'patches': 'http://review.rdoproject.org/r/openstack/nova.git',
             'distgit': 'git://git.example.com/rpms/nova',
             'master-distgit':
                 'git://git.example.com/rpms/nova',
@@ -183,7 +194,7 @@ class TestDriverDownstream(base.TestCase):
             'project': 'nova',
             'conf': 'rpmfactory-core',
             'upstream': 'git://git.openstack.org/openstack/nova',
-            'patches': 'http://review.rdoproject.org/r/p/openstack/nova.git',
+            'patches': 'http://review.rdoproject.org/r/openstack/nova.git',
             'distgit': 'git://git.example.com/rpms/nova',
             'master-distgit':
                 'git://git.example.com/rpms/nova',
@@ -238,7 +249,7 @@ class TestDriverDownstream(base.TestCase):
             'project': 'nova',
             'conf': 'rpmfactory-core',
             'upstream': 'git://git.openstack.org/openstack/nova',
-            'patches': 'http://review.rdoproject.org/r/p/openstack/nova.git',
+            'patches': 'http://review.rdoproject.org/r/openstack/nova.git',
             'distgit': 'git://git.example.com/rpms/nova',
             'master-distgit':
                 'git://git.example.com/rpms/nova',
@@ -270,7 +281,7 @@ class TestDriverDownstream(base.TestCase):
             'project': 'nova',
             'conf': 'rpmfactory-core',
             'upstream': 'git://git.openstack.org/openstack/nova',
-            'patches': 'http://review.rdoproject.org/r/p/openstack/nova.git',
+            'patches': 'http://review.rdoproject.org/r/openstack/nova.git',
             'distgit': 'git://git.example.com/rpms/nova',
             'master-distgit':
                 'git://git.example.com/rpms/nova',
@@ -319,7 +330,7 @@ class TestDriverDownstream(base.TestCase):
         expected = '%global with_doc 0\nfoo'
         self.assertEqual(result, expected)
 
-    @mock.patch('os.environ.get', side_effect=['myuser'])
+    @mock.patch('os.environ.get', side_effect=_mocked_get_environ)
     @mock.patch('sh.env', create=True)
     @mock.patch('os.listdir', side_effect=_mocked_listdir)
     def test_custom_preprocess(self, ld_mock, sh_mock, get_mock, uo_mock):
@@ -333,14 +344,18 @@ class TestDriverDownstream(base.TestCase):
              'DLRN_UPSTREAM_DISTGIT=%s/foo_distro_upstream/' % self.temp_dir,
              'DLRN_SOURCEDIR=%s/foo' % self.temp_dir,
              'DLRN_USER=myuser',
+             'DLRN_DATADIR=%s' % self.config.datadir,
              '/bin/true'],
             _cwd='%s/foo_distro/' % self.temp_dir,
-            _env={'LANG': 'C'})]
+            _env={'LANG': 'C',
+                  'MOCK_CONFIG': '/tmp/test.cfg',
+                  'RELEASE_DATE': '20150102034455',
+                  'RELEASE_NUMBERING': '0.date.hash'})]
 
         self.assertEqual(sh_mock.call_args_list, expected)
         self.assertEqual(sh_mock.call_count, 1)
 
-    @mock.patch('os.environ.get', side_effect=['myuser'])
+    @mock.patch('os.environ.get', side_effect=_mocked_get_environ)
     @mock.patch('sh.env', create=True)
     @mock.patch('os.listdir', side_effect=_mocked_listdir)
     def test_custom_preprocess_distroinfo(self, ld_mock, sh_mock, get_mock,
@@ -357,14 +372,18 @@ class TestDriverDownstream(base.TestCase):
              'DLRN_DISTROINFO_REPO=/tmp/test/dsinfo.yml',
              'DLRN_SOURCEDIR=%s/foo' % self.temp_dir,
              'DLRN_USER=myuser',
+             'DLRN_DATADIR=%s' % self.config.datadir,
              '/bin/true'],
             _cwd='%s/foo_distro/' % self.temp_dir,
-            _env={'LANG': 'C'})]
+            _env={'LANG': 'C',
+                  'MOCK_CONFIG': '/tmp/test.cfg',
+                  'RELEASE_DATE': '20150102034455',
+                  'RELEASE_NUMBERING': '0.date.hash'})]
 
         self.assertEqual(sh_mock.call_args_list, expected)
         self.assertEqual(sh_mock.call_count, 1)
 
-    @mock.patch('os.environ.get', side_effect=['myuser'])
+    @mock.patch('os.environ.get', side_effect=_mocked_get_environ)
     @mock.patch('sh.env', create=True)
     @mock.patch('os.listdir', side_effect=_mocked_listdir)
     @mock.patch('shutil.copy')
@@ -381,9 +400,13 @@ class TestDriverDownstream(base.TestCase):
              'DLRN_UPSTREAM_DISTGIT=%s/foo_distro_upstream/' % self.temp_dir,
              'DLRN_SOURCEDIR=%s/foo' % self.temp_dir,
              'DLRN_USER=myuser',
+             'DLRN_DATADIR=%s' % self.config.datadir,
              '/bin/true'],
             _cwd='%s/foo_distro/' % self.temp_dir,
-            _env={'LANG': 'C'})]
+            _env={'LANG': 'C',
+                  'MOCK_CONFIG': '/tmp/test.cfg',
+                  'RELEASE_DATE': '20150102034455',
+                  'RELEASE_NUMBERING': '0.date.hash'})]
 
         self.assertEqual(sh_mock.call_args_list, expected)
         self.assertEqual(sh_mock.call_count, 1)
@@ -391,7 +414,7 @@ class TestDriverDownstream(base.TestCase):
     @mock.patch('dlrn.drivers.downstream.DownstreamInfoDriver.'
                 '_restore_changelog')
     @mock.patch('dlrn.drivers.downstream.DownstreamInfoDriver._save_changelog')
-    @mock.patch('os.environ.get', side_effect=['myuser'])
+    @mock.patch('os.environ.get', side_effect=_mocked_get_environ)
     @mock.patch('sh.env', create=True)
     @mock.patch('os.listdir', side_effect=_mocked_listdir)
     @mock.patch('shutil.copy')
@@ -411,9 +434,13 @@ class TestDriverDownstream(base.TestCase):
              'DLRN_UPSTREAM_DISTGIT=%s/foo_distro_upstream/' % self.temp_dir,
              'DLRN_SOURCEDIR=%s/foo' % self.temp_dir,
              'DLRN_USER=myuser',
+             'DLRN_DATADIR=%s' % self.config.datadir,
              '/bin/true'],
             _cwd='%s/foo_distro/' % self.temp_dir,
-            _env={'LANG': 'C'})]
+            _env={'LANG': 'C',
+                  'MOCK_CONFIG': '/tmp/test.cfg',
+                  'RELEASE_DATE': '20150102034455',
+                  'RELEASE_NUMBERING': '0.date.hash'})]
 
         self.assertEqual(sh_mock.call_args_list, expected)
         self.assertEqual(sh_mock.call_count, 1)
