@@ -184,6 +184,34 @@ class TestcivoteQuery(DLRNAPIGraphQLTestCase):
         data = json.loads(response.data)
         self.assertEqual(len(data['data']['civote']), 5)
 
+    def test_get_offset(self, db_mock):
+        query = """
+            query {
+                civote(offset: 2)
+                {
+                    id
+                }
+            }
+        """
+        response = self.app.get('/api/graphql?query=%s' % query)
+        self.assertEqual(response.status_code, 200)
+        data = json.loads(response.data)
+        self.assertEqual(len(data['data']['civote']), 3)
+
+    def test_get_limit(self, db_mock):
+        query = """
+            query {
+                civote(limit: 2)
+                {
+                    id
+                }
+            }
+        """
+        response = self.app.get('/api/graphql?query=%s' % query)
+        self.assertEqual(response.status_code, 200)
+        data = json.loads(response.data)
+        self.assertEqual(len(data['data']['civote']), 2)
+
     def test_filtered_query(self, db_mock):
         query = """
             query {
@@ -212,6 +240,62 @@ class TestcivoteQuery(DLRNAPIGraphQLTestCase):
         data = json.loads(response.data)
         self.assertEqual(len(data['data']['civote']), 1)
 
+    def test_filtered_query_civote_true(self, db_mock):
+        query = """
+            query {
+                civote(ciVote: true)
+                {
+                    id
+                }
+            }
+        """
+        response = self.app.get('/api/graphql?query=%s' % query)
+        self.assertEqual(response.status_code, 200)
+        data = json.loads(response.data)
+        self.assertEqual(len(data['data']['civote']), 4)
+
+    def test_filtered_query_civote_false(self, db_mock):
+        query = """
+            query {
+                civote(ciVote: false)
+                {
+                    id
+                }
+            }
+        """
+        response = self.app.get('/api/graphql?query=%s' % query)
+        self.assertEqual(response.status_code, 200)
+        data = json.loads(response.data)
+        self.assertEqual(len(data['data']['civote']), 1)
+
+    def test_filtered_query_inprogress_true(self, db_mock):
+        query = """
+            query {
+                civote(ciInProgress: true)
+                {
+                    id
+                }
+            }
+        """
+        response = self.app.get('/api/graphql?query=%s' % query)
+        self.assertEqual(response.status_code, 200)
+        data = json.loads(response.data)
+        self.assertEqual(len(data['data']['civote']), 1)
+
+    def test_filtered_query_inprogress_false(self, db_mock):
+        query = """
+            query {
+                civote(ciInProgress: false)
+                {
+                    id
+                }
+            }
+        """
+        response = self.app.get('/api/graphql?query=%s' % query)
+        self.assertEqual(response.status_code, 200)
+        data = json.loads(response.data)
+        self.assertEqual(len(data['data']['civote']), 4)
+
     def test_badfiltered_query(self, db_mock):
         query = """
             query {
@@ -243,10 +327,11 @@ class TestcivoteQuery(DLRNAPIGraphQLTestCase):
         data = json.loads(response.data)
         self.assertEqual(len(data['data']['civote']), 2)
         self.assertEqual(data['data']['civote'][0]['commitId'], 5627)
-        self.assertEqual(data['data']['civote'][0]['ciName'], 'consistent')
-        self.assertEqual(data['data']['civote'][0]['ciVote'], True)
-        self.assertEqual(data['data']['civote'][0]['ciInProgress'], False)
-        self.assertEqual(data['data']['civote'][0]['timestamp'], 1441635089)
+        self.assertEqual(data['data']['civote'][0]['ciName'],
+                         'current-passed-ci')
+        self.assertEqual(data['data']['civote'][0]['ciVote'], False)
+        self.assertEqual(data['data']['civote'][0]['ciInProgress'], True)
+        self.assertEqual(data['data']['civote'][0]['timestamp'], 1441635090)
         self.assertEqual(data['data']['civote'][0]['user'], 'foo')
         assert 'component' not in data['data']['civote'][0]
 
@@ -259,6 +344,34 @@ class TestCIVoteAggregationQuery(DLRNAPIGraphQLTestCase):
         data = json.loads(response.data)
         self.assertEqual(len(data['data']['civoteAgg']), 3)
 
+    def test_get_offset(self, db_mock):
+        query = """
+            query {
+                civoteAgg(offset: 2)
+                {
+                    id
+                }
+            }
+        """
+        response = self.app.get('/api/graphql?query=%s' % query)
+        self.assertEqual(response.status_code, 200)
+        data = json.loads(response.data)
+        self.assertEqual(len(data['data']['civoteAgg']), 1)
+
+    def test_get_limit(self, db_mock):
+        query = """
+            query {
+                civoteAgg(limit: 2)
+                {
+                    id
+                }
+            }
+        """
+        response = self.app.get('/api/graphql?query=%s' % query)
+        self.assertEqual(response.status_code, 200)
+        data = json.loads(response.data)
+        self.assertEqual(len(data['data']['civoteAgg']), 2)
+
     def test_filtered_query(self, db_mock):
         query = """
             query {
@@ -273,6 +386,62 @@ class TestCIVoteAggregationQuery(DLRNAPIGraphQLTestCase):
         data = json.loads(response.data)
         self.assertEqual(len(data['data']['civoteAgg']), 2)
 
+    def test_filtered_civote_true(self, db_mock):
+        query = """
+            query {
+                civoteAgg(ciVote: true)
+                {
+                    id
+                }
+            }
+        """
+        response = self.app.get('/api/graphql?query=%s' % query)
+        self.assertEqual(response.status_code, 200)
+        data = json.loads(response.data)
+        self.assertEqual(len(data['data']['civoteAgg']), 2)
+
+    def test_filtered_civote_false(self, db_mock):
+        query = """
+            query {
+                civoteAgg(ciVote: false)
+                {
+                    id
+                }
+            }
+        """
+        response = self.app.get('/api/graphql?query=%s' % query)
+        self.assertEqual(response.status_code, 200)
+        data = json.loads(response.data)
+        self.assertEqual(len(data['data']['civoteAgg']), 1)
+
+    def test_filtered_ciinprogress_false(self, db_mock):
+        query = """
+            query {
+                civoteAgg(ciInProgress: false)
+                {
+                    id
+                }
+            }
+        """
+        response = self.app.get('/api/graphql?query=%s' % query)
+        self.assertEqual(response.status_code, 200)
+        data = json.loads(response.data)
+        self.assertEqual(len(data['data']['civoteAgg']), 3)
+
+    def test_filtered_ciinprogress_true(self, db_mock):
+        query = """
+            query {
+                civoteAgg(ciInProgress: true)
+                {
+                    id
+                }
+            }
+        """
+        response = self.app.get('/api/graphql?query=%s' % query)
+        self.assertEqual(response.status_code, 200)
+        data = json.loads(response.data)
+        self.assertEqual(len(data['data']['civoteAgg']), 0)
+
     def test_badfiltered_query(self, db_mock):
         query = """
             query {
@@ -309,10 +478,10 @@ class TestCIVoteAggregationQuery(DLRNAPIGraphQLTestCase):
         self.assertEqual(data['data']['civoteAgg'][0]['ciName'], 'phase2-ci')
         self.assertEqual(data['data']['civoteAgg'][0]['ciUrl'],
                          'http://dummyci.example.com/phase2-ci')
-        self.assertEqual(data['data']['civoteAgg'][0]['ciVote'], True)
+        self.assertEqual(data['data']['civoteAgg'][0]['ciVote'], False)
         self.assertEqual(data['data']['civoteAgg'][0]['ciInProgress'], False)
         self.assertEqual(data['data']['civoteAgg'][0]['timestamp'],
-                         1441635095)
+                         1441635195)
         self.assertEqual(data['data']['civoteAgg'][0]['notes'], '')
         assert 'user' not in data['data']['civoteAgg'][0]
 
