@@ -6,7 +6,7 @@ set -ex
 # ./run_tests.sh <path_to_rdoinfo> <distro (either centos or fedora)> <baseurl to trunk repo> <tag (optional)>
 
 # Simple script to test that DLRN works either locally or in a zuul environment
-GIT_BASE_URL="https://review.rdoproject.org/r/p"
+GIT_BASE_URL="https://review.rdoproject.org/r"
 OPENSTACK_GIT_URL="https://opendev.org"
 ZUUL3_HOME="${ZUUL3_HOME:-/home/zuul}"
 ZUUL_CLONES_DIR="${ZUUL3_HOME}/src/review.rdoproject.org"
@@ -161,16 +161,13 @@ for PROJECT_TO_BUILD in ${PROJECTS_TO_BUILD}; do
         UPSTREAM_URL=$(rdopkg findpkg $PROJECT_TO_BUILD -l /tmp/rdoinfo | grep ^upstream | awk '{print $2}')
         UPSTREAM_URL_REDIRECTED=$(curl -Ls -w %{url_effective} -o /dev/null ${UPSTREAM_URL})
         UPSTREAM_PROJECT_NAME=${UPSTREAM_URL_REDIRECTED/https:\/\/opendev.org\//}
-        rm -rf data/${PROJECT_TO_BUILD_MAPPED}
         # Only build in the check pipeline to avoid merging a change
         # in packaging that is dependent of an non merged upstream
         # change
-        git clone ${UPSTREAM_URL_REDIRECTED} "data/${PROJECT_TO_BUILD_MAPPED}"
-        if [ "${ZUUL_PIPELINE}" != "check" ]; then
-            NOT_EXTRACTED=1
-        fi
+        if [ "${ZUUL_PIPELINE}" == "check" ]; then
+            rm -rf data/${PROJECT_TO_BUILD_MAPPED}
+            git clone ${UPSTREAM_URL_REDIRECTED} "data/${PROJECT_TO_BUILD_MAPPED}"
 
-        if [ -z "$NOT_EXTRACTED" ]; then
             # We cannot run git review -d because we don't have an
             # available account. So we do the same using curl, jq and git.
             if [ "$branch" != "" ]; then
